@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-"""Color Library
+"""Color Library.
 
 .. :doctest:
 
@@ -33,18 +32,32 @@ Please see the documentation of this object for more information.
 .. note:: Some constants are defined for convenience in HSL, RGB, HEX
 
 """
-
-from __future__ import with_statement, print_function
+from __future__ import annotations
 
 import hashlib
 import re
-import sys
-
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterator,
+    List,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+    cast,
+)
 
 ##
 # Some Constants
 ##
 
+_Hsl = Tuple[float, float, float]
+_Rgb = Tuple[float, float, float]
+_Hex = str
+_Web = str
+
 # Soften inequalities and some rounding issue based on float
 FLOAT_ERROR = 0.0000005
 
@@ -80,6 +93,7 @@ RGB_TO_COLOR_NAMES = {
     (85, 107, 47): ["DarkOliveGreen"],
     (95, 158, 160): ["CadetBlue"],
     (100, 149, 237): ["CornflowerBlue"],
+    (102, 51, 153): ["RebeccaPurple"],
     (102, 205, 170): ["MediumAquamarine"],
     (105, 105, 105): ["DimGray", "DimGrey"],
     (106, 90, 205): ["SlateBlue"],
@@ -192,7 +206,7 @@ RGB_TO_COLOR_NAMES = {
 }
 
 # Building inverse relation
-COLOR_NAME_TO_RGB = dict(
+COLOR_NAME_TO_RGB: Dict[str, Tuple[int, int, int]] = dict(
     (name.lower(), rgb)
     for rgb, names in RGB_TO_COLOR_NAMES.items()
     for name in names
@@ -204,12 +218,36 @@ SHORT_HEX_COLOR = re.compile(r"^#[0-9a-fA-F]{3}$")
 
 
 class C_HSL:
-    def __getattr__(self, value):
+    """HSL colors container.
+
+    Provides a quick color access.
+
+    >>> from colour import HSL
+
+    >>> HSL.WHITE
+    (0.0, 0.0, 1.0)
+    >>> HSL.BLUE # doctest: +ELLIPSIS
+    (0.66..., 1.0, 0.5)
+
+    >>> HSL.DONOTEXISTS  # doctest: +ELLIPSIS
+    Traceback (most recent call last):
+    ...
+    AttributeError: ... has no attribute 'DONOTEXISTS'
+
+    """
+
+    def __getattr__(self, value: str) -> _Hsl:
+        """Get hsl value of a color by its name."""
         label = value.lower()
         if label in COLOR_NAME_TO_RGB:
-            return rgb2hsl(tuple(v / 255.0 for v in COLOR_NAME_TO_RGB[label]))
+            return rgb2hsl(
+                cast(
+                    _Hsl,
+                    tuple(v / 255.0 for v in COLOR_NAME_TO_RGB[label]),
+                )
+            )
         raise AttributeError(
-            "%s instance has no attribute %r" % (self.__class__, value)
+            f"{self.__class__} instance has no attribute {value!r}"
         )
 
 
@@ -217,7 +255,7 @@ HSL = C_HSL()
 
 
 class C_RGB:
-    """RGB colors container
+    """RGB colors container.
 
     Provides a quick color access.
 
@@ -235,12 +273,13 @@ class C_RGB:
 
     """
 
-    def __getattr__(self, value):
+    def __getattr__(self, value: str) -> _Rgb:
+        """Get rgb value of a color by its name."""
         return hsl2rgb(getattr(HSL, value))
 
 
 class C_HEX:
-    """RGB colors container
+    """RGB colors container.
 
     Provides a quick color access.
 
@@ -258,7 +297,8 @@ class C_HEX:
 
     """
 
-    def __getattr__(self, value):
+    def __getattr__(self, value: str) -> _Hex:
+        """Get hex value of a color by its name."""
         return rgb2hex(getattr(RGB, value))
 
 
@@ -271,8 +311,8 @@ HEX = C_HEX()
 ##
 
 
-def hsl2rgb(hsl):
-    """Convert HSL representation towards RGB
+def hsl2rgb(hsl: _Hsl) -> _Rgb:
+    """Convert HSL representation towards RGB.
 
     :param h: Hue, position around the chromatic circle (h=1 equiv h=0)
     :param s: Saturation, color saturation (0=full gray, 1=full color)
@@ -345,32 +385,32 @@ def hsl2rgb(hsl):
     ValueError: Lightness must be between 0 and 1.
 
     """
-    h, s, l = [float(v) for v in hsl]
+    hue, sat, lit = [float(v) for v in hsl]
 
-    if not (0.0 - FLOAT_ERROR <= s <= 1.0 + FLOAT_ERROR):
+    if not (0.0 - FLOAT_ERROR <= sat <= 1.0 + FLOAT_ERROR):
         raise ValueError("Saturation must be between 0 and 1.")
-    if not (0.0 - FLOAT_ERROR <= l <= 1.0 + FLOAT_ERROR):
+    if not (0.0 - FLOAT_ERROR <= lit <= 1.0 + FLOAT_ERROR):
         raise ValueError("Lightness must be between 0 and 1.")
 
-    if s == 0:
-        return l, l, l
+    if sat == 0:
+        return lit, lit, lit
 
-    if l < 0.5:
-        v2 = l * (1.0 + s)
+    if lit < 0.5:
+        v2 = lit * (1.0 + sat)
     else:
-        v2 = (l + s) - (s * l)
+        v2 = (lit + sat) - (sat * lit)
 
-    v1 = 2.0 * l - v2
+    v1 = 2.0 * lit - v2
 
-    r = _hue2rgb(v1, v2, h + (1.0 / 3))
-    g = _hue2rgb(v1, v2, h)
-    b = _hue2rgb(v1, v2, h - (1.0 / 3))
+    red = _hue2rgb(v1, v2, hue + (1.0 / 3))
+    green = _hue2rgb(v1, v2, hue)
+    blue = _hue2rgb(v1, v2, hue - (1.0 / 3))
 
-    return r, g, b
+    return red, green, blue
 
 
-def rgb2hsl(rgb):
-    """Convert RGB representation towards HSL
+def rgb2hsl(rgb: _Rgb) -> _Hsl:
+    """Convert RGB representation towards HSL.
 
     :param r: Red amount (float between 0 and 1)
     :param g: Green amount (float between 0 and 1)
@@ -437,7 +477,7 @@ def rgb2hsl(rgb):
     for name, v in {"Red": r, "Green": g, "Blue": b}.items():
         if not (0 - FLOAT_ERROR <= v <= 1 + FLOAT_ERROR):
             raise ValueError(
-                "%s must be between 0 and 1. You provided %r." % (name, v)
+                f"{name} must be between 0 and 1. You provided {v!r}."
             )
 
     vmin = min(r, g, b)  # Min. value of RGB
@@ -446,17 +486,17 @@ def rgb2hsl(rgb):
 
     vsum = vmin + vmax
 
-    l = vsum / 2
+    lit = vsum / 2
 
     if diff < FLOAT_ERROR:  # This is a gray, no chroma...
-        return (0.0, 0.0, l)
+        return (0.0, 0.0, lit)
 
     ##
     # Chromatic data...
     ##
 
     # Saturation
-    if l < 0.5:
+    if lit < 0.5:
         s = diff / vsum
     else:
         s = diff / (2.0 - vsum)
@@ -477,16 +517,15 @@ def rgb2hsl(rgb):
     if h > 1:
         h -= 1
 
-    return (h, s, l)
+    return (h, s, lit)
 
 
-def _hue2rgb(v1, v2, vH):
-    """Private helper function (Do not call directly)
+def _hue2rgb(v1: float, v2: float, vH: float) -> float:
+    """Private helper function (Do not call directly).
 
     :param vH: rotation around the chromatic circle (between 0..1)
 
     """
-
     while vH < 0:
         vH += 1
     while vH > 1:
@@ -502,8 +541,8 @@ def _hue2rgb(v1, v2, vH):
     return v1
 
 
-def rgb2hex(rgb, force_long=False):
-    """Transform RGB tuple to hex RGB representation
+def rgb2hex(rgb: _Rgb, force_long: float = False) -> _Hex:
+    """Transform RGB tuple to hex RGB representation.
 
     :param rgb: RGB 3-uple of float between 0 and 1
     :rtype: 3 hex char or 6 hex char string representation
@@ -530,17 +569,16 @@ def rgb2hex(rgb, force_long=False):
     '#00ffff'
 
     """
-
-    hx = "".join(["%02x" % int(c * 255 + 0.5 - FLOAT_ERROR) for c in rgb])
+    hx = "".join([f"{int(c * 255 + 0.5 - FLOAT_ERROR):02x}" for c in rgb])
 
     if not force_long and hx[0::2] == hx[1::2]:
         hx = "".join(hx[0::2])
 
-    return "#%s" % hx
+    return f"#{hx}"
 
 
-def hex2rgb(str_rgb):
-    """Transform hex RGB representation to RGB tuple
+def hex2rgb(str_rgb: _Hex) -> _Rgb:
+    """Transform hex RGB representation to RGB tuple.
 
     :param str_rgb: 3 hex char or 6 hex char string representation
     :rtype: RGB 3-uple of float between 0 and 1
@@ -562,24 +600,23 @@ def hex2rgb(str_rgb):
     ValueError: Invalid value '#aa' provided for rgb color.
 
     """
+    rgb = str_rgb[1:]
 
-    try:
-        rgb = str_rgb[1:]
+    if len(rgb) == 6:
+        r, g, b = rgb[0:2], rgb[2:4], rgb[4:6]
+    elif len(rgb) == 3:
+        r, g, b = rgb[0] * 2, rgb[1] * 2, rgb[2] * 2
+    else:
+        raise ValueError(f"Invalid value {str_rgb!r} provided for rgb color.")
 
-        if len(rgb) == 6:
-            r, g, b = rgb[0:2], rgb[2:4], rgb[4:6]
-        elif len(rgb) == 3:
-            r, g, b = rgb[0] * 2, rgb[1] * 2, rgb[2] * 2
-        else:
-            raise ValueError()
-    except BaseException:
-        raise ValueError("Invalid value %r provided for rgb color." % str_rgb)
-
-    return tuple([float(int(v, 16)) / 255 for v in (r, g, b)])
+    return cast(
+        Tuple[float, float, float],
+        tuple(float(int(v, 16)) / 255 for v in (r, g, b)),
+    )
 
 
-def hex2web(hex):
-    """Converts HEX representation to WEB
+def hex2web(hex_color: _Hex) -> _Web:
+    """Convert HEX representation to WEB.
 
     :param rgb: 3 hex char or 6 hex char string representation
     :rtype: web string representation (human readable if possible)
@@ -605,7 +642,10 @@ def hex2web(hex):
     '#acacac'
 
     """
-    dec_rgb = tuple(int(v * 255) for v in hex2rgb(hex))
+    dec_rgb = cast(
+        Tuple[int, int, int],
+        tuple(int(v * 255) for v in hex2rgb(hex_color)),
+    )
     if dec_rgb in RGB_TO_COLOR_NAMES:
         # take the first one
         color_name = RGB_TO_COLOR_NAMES[dec_rgb][0]
@@ -617,14 +657,18 @@ def hex2web(hex):
         )
 
     # Hex format is verified by hex2rgb function. And should be 3 or 6 digit
-    if len(hex) == 7:
-        if hex[1] == hex[2] and hex[3] == hex[4] and hex[5] == hex[6]:
-            return "#" + hex[1] + hex[3] + hex[5]
-    return hex
+    if len(hex_color) == 7:
+        if (
+            hex_color[1] == hex_color[2]
+            and hex_color[3] == hex_color[4]
+            and hex_color[5] == hex_color[6]
+        ):
+            return "#" + hex_color[1] + hex_color[3] + hex_color[5]
+    return hex_color
 
 
-def web2hex(web, force_long=False):
-    """Converts WEB representation to HEX
+def web2hex(web: _Web, force_long: bool = False) -> _Hex:
+    """Convert WEB representation to HEX.
 
     :param rgb: web string representation (human readable if possible)
     :rtype: 3 hex char or 6 hex char string representation
@@ -676,51 +720,65 @@ def web2hex(web, force_long=False):
         ):
             return web.lower()
         elif SHORT_HEX_COLOR.match(web) and force_long:
-            return "#" + "".join([("%s" % (t,)) * 2 for t in web[1:]])
+            return "#" + "".join([(f"{t}") * 2 for t in web[1:]])
         raise AttributeError(
-            "%r is not in web format. Need 3 or 6 hex digit." % web
+            f"{web!r} is not in web format. Need 3 or 6 hex digit."
         )
 
     web = web.lower()
     if web not in COLOR_NAME_TO_RGB:
-        raise ValueError("%r is not a recognized color." % web)
+        raise ValueError(f"{web!r} is not a recognized color.")
 
     # convert dec to hex:
 
     return rgb2hex(
-        [float(int(v)) / 255 for v in COLOR_NAME_TO_RGB[web]], force_long
+        cast(
+            Tuple[float, float, float],
+            tuple(float(int(v)) / 255 for v in COLOR_NAME_TO_RGB[web]),
+        ),
+        force_long,
     )
 
 
 # Missing functions conversion
 
 
-def hsl2hex(x):
+def hsl2hex(x: _Hsl) -> _Hex:
+    """Convert color from hsl to hex."""
     return rgb2hex(hsl2rgb(x))
 
 
-def hex2hsl(x):
+def hex2hsl(x: _Hex) -> _Hsl:
+    """Convert color from hex to hsl."""
     return rgb2hsl(hex2rgb(x))
 
 
-def rgb2web(x):
+def rgb2web(x: _Rgb) -> _Web:
+    """Convert color from rgb to web."""
     return hex2web(rgb2hex(x))
 
 
-def web2rgb(x):
+def web2rgb(x: _Web) -> _Rgb:
+    """Convert color from web to rgb."""
     return hex2rgb(web2hex(x))
 
 
-def web2hsl(x):
+def web2hsl(x: _Web) -> _Hsl:
+    """Convert color from web to hsl."""
     return rgb2hsl(web2rgb(x))
 
 
-def hsl2web(x):
+def hsl2web(x: _Hsl) -> _Web:
+    """Convert color from hsl to web."""
     return rgb2web(hsl2rgb(x))
 
 
-def color_scale(begin_hsl, end_hsl, nb):
-    """Returns a list of nb color HSL tuples between begin_hsl and end_hsl
+def color_scale(
+    begin_hsl: _Hsl,
+    end_hsl: _Hsl,
+    nb: int,
+) -> Sequence[_Hsl]:
+    """Return a list of nb color HSL tuples between begin_hsl and end_hsl.
 
     >>> from colour import color_scale
 
@@ -742,21 +800,24 @@ def color_scale(begin_hsl, end_hsl, nb):
     ValueError: Unsupported negative number of colors (nb=-2).
 
     """
-
     if nb < 0:
-        raise ValueError("Unsupported negative number of colors (nb=%r)." % nb)
+        raise ValueError(f"Unsupported negative number of colors (nb={nb!r}).")
 
-    step = (
+    step: _Hsl = cast(
+        _Hsl,
         tuple([float(end_hsl[i] - begin_hsl[i]) / nb for i in range(0, 3)])
         if nb > 0
-        else (0, 0, 0)
+        else (0, 0, 0),
     )
 
-    def mul(step, value):
-        return tuple([v * value for v in step])
+    def mul(step: _Hsl, value: int) -> _Hsl:
+        return cast(_Hsl, tuple([v * value for v in step]))
 
-    def add_v(step, step2):
-        return tuple([v + step2[i] for i, v in enumerate(step)])
+    def add_v(step: _Hsl, step2: _Hsl) -> _Hsl:
+        return cast(
+            _Hsl,
+            tuple([v + step2[i] for i, v in enumerate(step)]),
+        )
 
     return [add_v(begin_hsl, mul(step, r)) for r in range(0, nb + 1)]
 
@@ -766,8 +827,8 @@ def color_scale(begin_hsl, end_hsl, nb):
 ##
 
 
-def RGB_color_picker(obj):
-    """Build a color representation from the string representation of an object
+def RGB_color_picker(obj: object) -> Color:
+    """Build a color representation from the string representation of an object.
 
     This allows to quickly get a color from some data, with the
     additional benefit that the color will be the same as long as the
@@ -791,7 +852,6 @@ def RGB_color_picker(obj):
         True
 
     """
-
     # Turn the input into a by 3-dividable string. SHA-384 is good because it
     # divides into 3 components of the same size, which will be used to
     # represent the RGB values of the color.
@@ -806,16 +866,27 @@ def RGB_color_picker(obj):
     # Convert those hexadecimal sub-strings into integer and scale them down
     # to the 0..1 range.
     max_value = float(int("f" * subsize, 16))
-    components = (
-        int(d, 16)  # Make a number from a list with hex digits
-        / max_value  # Scale it down to [0.0, 1.0]
-        for d in splitted_digest
+    components = cast(
+        _Rgb,
+        tuple(
+            # Make a number from a list with hex digits
+            # Scale it down to [0.0, 1.0]
+            int(d, 16) / max_value
+            for d in splitted_digest
+        ),
     )
 
     return Color(rgb2hex(components))  # Profit!
 
 
-def hash_or_str(obj):
+def hash_or_str(obj: object) -> Union[int, str]:
+    """Convert an object into a unique hash.
+
+    Parameters
+    ----------
+    obj
+        object to be converted
+    """
     try:
         return hash((type(obj).__name__, obj))
     except TypeError:
@@ -824,13 +895,23 @@ def hash_or_str(obj):
         return type(obj).__name__ + str(obj)
 
 
+def RGB_equivalence(c1: Color, c2: Color) -> bool:
+    """Compare whether two colors are equivalent according to their RGB values."""
+    return c1.hex_l == c2.hex_l
+
+
+def HSL_equivalence(c1: Color, c2: Color) -> bool:
+    """Compare whether two colors are equivalent according to their HSL values."""
+    return c1._hsl == c2._hsl
+
+
 ##
 # All purpose object
 ##
 
 
 class Color(object):
-    """Abstraction of a color object
+    """Abstraction of a color object.
 
     Color object keeps information of a color. It can input/output to different
     format (HSL, RGB, HEX, WEB) and their partial representation.
@@ -1005,20 +1086,35 @@ class Color(object):
 
     """
 
-    _hsl = None  # internal representation
+    equality = staticmethod(RGB_equivalence)
 
     def __init__(
         self,
-        color=None,
-        pick_for=None,
-        picker=RGB_color_picker,
-        pick_key=hash_or_str,
-        **kwargs
-    ):
+        color: Optional[Union[_Web, Color]] = None,
+        pick_for: Optional[object] = None,
+        picker: Callable[[object], Color] = RGB_color_picker,
+        pick_key: Callable[[object], Union[str, int]] = hash_or_str,
+        **kwargs: Any,
+    ) -> None:
+        """Create ``Color``.
 
+        Parameters
+        ----------
+        color
+            The initializer of color. If left as ``None``, it defaults to black.
+
+        pick_for
+            The object to be hashed and converted into color.
+
+        picker
+            Method converting hash of an object into RGB color.
+
+        pick_key
+            Method picking a key from object to be hashed.
+        """
         if pick_key is None:
 
-            def pick_key(x):
+            def pick_key(x: object) -> object:
                 return x
 
         if pick_for is not None:
@@ -1029,140 +1125,202 @@ class Color(object):
         else:
             self.web = color if color else "black"
 
-        self.equality = RGB_equivalence
-
         for k, v in kwargs.items():
             setattr(self, k, v)
 
-    def __getattr__(self, label):
+    def __getattr__(self, label: str) -> Union[float, _Hsl, _Rgb, _Hex, _Web]:
+        """Transform getting attribute in the form ``color.foo`` to ``color.get_foo()`` whenever it is possible."""
         if label.startswith("get_"):
-            raise AttributeError("'%s' not found" % label)
+            raise AttributeError(f"'{label}' not found")
         try:
-            return getattr(self, "get_" + label)()
+            return cast(
+                Union[float, _Hsl, _Rgb, _Hex, _Web],
+                getattr(self, "get_" + label)(),
+            )
         except AttributeError:
-            raise AttributeError("'%s' not found" % label)
+            raise AttributeError(f"'{label}' not found")
 
-    def __setattr__(self, label, value):
+    def __setattr__(
+        self,
+        label: str,
+        value: Union[float, _Hsl, _Rgb, _Hex, _Web],
+    ) -> None:
+        """Transform assingments of the form ``color.foo = x`` to ``color.set_foo(x)`` whenever it is possible."""
         if label not in ["_hsl", "equality"]:
             fc = getattr(self, "set_" + label)
             fc(value)
         else:
             self.__dict__[label] = value
 
+    @property
+    def web(self) -> _Web:
+        """Get web notation of the color."""
+        return self.get_web()
+
+    @web.setter
+    def web(self, web: _Web) -> None:
+        self.set_web(web)
+
+    @property
+    def rgb(self) -> _Rgb:
+        """Get rgb notation of the color."""
+        return self.get_rgb()
+
+    @rgb.setter
+    def rgb(self, rgb: _Rgb) -> None:
+        self.set_rgb(rgb)
+
     ##
     # Get
     ##
 
-    def get_hsl(self):
-        return tuple(self._hsl)
+    def get_hsl(self) -> _Hsl:
+        """Get hsl notation of the color."""
+        return (self._hsl[0], self._hsl[1], self._hsl[2])
 
-    def get_hex(self):
+    def get_hex(self) -> _Hex:
+        """Get shortest possible hex notation of the color."""
         return rgb2hex(self.rgb)
 
-    def get_hex_l(self):
+    def get_hex_l(self) -> _Hex:
+        """Get long hex notation of the color."""
         return rgb2hex(self.rgb, force_long=True)
 
-    def get_rgb(self):
+    def get_rgb(self) -> _Rgb:
+        """Get rgb notation of the color."""
         return hsl2rgb(self.hsl)
 
-    def get_hue(self):
+    def get_hue(self) -> float:
+        """Get hue of the color."""
         return self.hsl[0]
 
-    def get_saturation(self):
+    def get_saturation(self) -> float:
+        """Get saturation of the color."""
         return self.hsl[1]
 
-    def get_luminance(self):
+    def get_luminance(self) -> float:
+        """Get luminance of the color."""
         return self.hsl[2]
 
-    def get_red(self):
+    def get_red(self) -> float:
+        """Get red component of the color."""
         return self.rgb[0]
 
-    def get_green(self):
+    def get_green(self) -> float:
+        """Get green component of the color."""
         return self.rgb[1]
 
-    def get_blue(self):
+    def get_blue(self) -> float:
+        """Get blue component of the color."""
         return self.rgb[2]
 
-    def get_web(self):
+    def get_web(self) -> _Web:
+        """Get web representation of the color."""
         return hex2web(self.hex)
 
     ##
     # Set
     ##
 
-    def set_hsl(self, value):
-        self._hsl = list(value)
+    def set_hsl(self, value: _Hsl) -> None:
+        """Set color using hsl notation."""
+        self._hsl: List[float] = list(value)
 
-    def set_rgb(self, value):
+    def set_rgb(self, value: _Rgb) -> None:
+        """Set color using rgb notation."""
         self.hsl = rgb2hsl(value)
 
-    def set_hue(self, value):
+    def set_hue(self, value: float) -> None:
+        """Set hue of the color."""
         self._hsl[0] = value
 
-    def set_saturation(self, value):
+    def set_saturation(self, value: float) -> None:
+        """Set saturation of the color."""
         self._hsl[1] = value
 
-    def set_luminance(self, value):
+    def set_luminance(self, value: float) -> None:
+        """Set luminance of the color."""
         self._hsl[2] = value
 
-    def set_red(self, value):
+    def set_red(self, value: float) -> None:
+        """Set red coordinate of the color."""
         _, g, b = self.rgb
         self.rgb = (value, g, b)
 
-    def set_green(self, value):
+    def set_green(self, value: float) -> None:
+        """Set green coordinate of the color."""
         r, _, b = self.rgb
         self.rgb = (r, value, b)
 
-    def set_blue(self, value):
+    def set_blue(self, value: float) -> None:
+        """Set blue coordinate of the color."""
         r, g, _ = self.rgb
         self.rgb = (r, g, value)
 
-    def set_hex(self, value):
+    def set_hex(self, value: _Hex) -> None:
+        """Set a color using hex notation."""
         self.rgb = hex2rgb(value)
 
     set_hex_l = set_hex
 
-    def set_web(self, value):
+    def set_web(self, value: _Web) -> None:
+        """Set a color using web notation."""
         self.hex = web2hex(value)
 
     # range of color generation
 
-    def range_to(self, value, steps):
-        for hsl in color_scale(self._hsl, Color(value).hsl, steps - 1):
+    def range_to(self, value: Color, steps: int) -> Iterator[Color]:
+        """Produce a uniform range of colors. starting with ``self`` and ending with ``value``."""
+        for hsl in color_scale(self.hsl, Color(value).hsl, steps - 1):
             yield Color(hsl=hsl)
 
     ##
     # Convenience
     ##
 
-    def __str__(self):
-        return "%s" % self.web
+    def __str__(self) -> str:
+        """Return a color in human readable form."""
+        return str(self.web)
 
-    def __repr__(self):
-        return "<Color %s>" % self.web
+    def __repr__(self) -> str:
+        """Return representation of color in human readable form."""
+        return f"<Color {self.web}>"
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
+        """Compare two colors according to the equality comparator of the first color."""
         if isinstance(other, Color):
             return self.equality(self, other)
         return NotImplemented
 
-    if sys.version_info[0] == 2:
-        # Note: intended to be a backport of python 3 behavior
-        def __ne__(self, other):
-            equal = self.__eq__(other)
-            return equal if equal is NotImplemented else not equal
+    ##
+    # Constructors
+    ##
+
+    @staticmethod
+    def from_hsl(hsl_value: _Hsl) -> Color:
+        """Return new ``Color`` object based on provided hsl vaue."""
+        return Color(hsl=hsl_value)
+
+    @staticmethod
+    def from_rgb(rgb_value: _Rgb) -> Color:
+        """Return new ``Color`` object based on provided rgb vaue."""
+        return Color(rgb=rgb_value)
+
+    @staticmethod
+    def from_hex(hex_value: _Hex) -> Color:
+        """Return new ``Color`` object based on provided hex vaue."""
+        return Color(hex=hex_value)
+
+    @staticmethod
+    def from_web(web_value: _Web) -> Color:
+        """Return new ``Color`` object based on provided web vaue."""
+        return Color(web=web_value)
 
 
-def RGB_equivalence(c1, c2):
-    return c1.hex_l == c2.hex_l
+def make_color_factory(**kwargs_defaults: Any) -> Callable[..., Color]:
+    """Create a factory of ``Color`` with given defaults."""
 
-
-def HSL_equivalence(c1, c2):
-    return c1._hsl == c2._hsl
-
-
-def make_color_factory(**kwargs_defaults):
-    def ColorFactory(*args, **kwargs):
+    def ColorFactory(*args: Any, **kwargs: Any) -> Color:
         new_kwargs = kwargs_defaults.copy()
         new_kwargs.update(kwargs)
         return Color(*args, **new_kwargs)
